if Fence:HasModule('Browse') then return end

local L = AceLibrary("AceLocale-2.2"):new("Fence_Browse")
local l = AceLibrary("AceLocale-2.2"):new("Fence")
local abc = AceLibrary("Abacus-2.0")

-- Localization
L:RegisterTranslations("enUS", function() return {
		["Browse"] = true,
		["Show Bid"] = true,
		["Show Single-Price"] = true,
		["Single-Price Style"] = true,
		["Changes single-price style."] = true,
		["Bid"] = true,
        ["Changes bid style."] = true,
        ["Bid Style"] = true,
	}
end)

L:RegisterTranslations("deDE", function() return {
		["Browse"] = "Browse",
		["Show Bid"] = "Gebotanzeige",
		["Show Single-Price"] = "Einzelpreis-Anzeige",
		["Single-Price Style"] = "Einzelpreis-Stil",
		["Changes single-price style."] = "Stil f\195\188r Einzelpreis anpassen.",
		["Bid"] = "Gebot",
        ["Changes bid style."] = "Stil f\195\188r Gebote anpassen.",
        ["Bid Style"] = "Gebot-Stil"
	}
end)

local mod = Fence:NewModule("Browse")

Fence:RegisterDefaults('Browse', 'profile', {
	ShowPrice = true,
    ShowBid = true,
    PriceStyle = "short",
    BidStyle = "fade"
})

mod.db = Fence:AcquireDBNamespace("Browse")
	
	function mod:OnInitialize()
		
        self:Update()
        
		Fence.options.args.browse = {
			type = 'group',
			name = L["Browse"], aliases='br',
			desc = string.format(l["%s options"], L["Browse"]),
				args = {
					toggle = {
						type = 'toggle',
						name = L["Browse"],
						desc = string.format(l["Toggles %s function."], L["Browse"]),
						get = function() return Fence:IsModuleActive("Browse") end,
						set = function(v) Fence:ToggleModuleActive("Browse", v) end
					},
					showprice = {
						type = 'toggle',
						name = L["Show Single-Price"], aliases='sp',
						desc = string.format(l["Toggles %s function."], L["Show Single-Price"]),
						get = function() return self.db.profile.ShowPrice end,
						set = function(v) self.db.profile.ShowPrice = v self:Update() end
					},
					pricestyle= {
						type = 'text',
						name = L["Single-Price Style"], aliases = 'ps',
						desc = L["Changes single-price style."],
						get = function() return self.db.profile.PriceStyle end,
						set = function(v) self.db.profile.PriceStyle= v self:Update() end,
						validate = {"short", "full", "condensed"}
					},
					showbid = {
						type = 'toggle',
						name = L["Show Bid"], aliases='sb',
						desc = string.format(l["Toggles %s function."], L["Show Bid"]),
						get = function() return self.db.profile.ShowBid end,
						set = function(v) self.db.profile.ShowBid = v self:Update() end
					},
  					bidstyle = {
						type = 'text',
						name = L["Bid Style"], aliases='bs',
						desc = L["Changes bid style."],
						get = function() return self.db.profile.BidStyle end,
						set = function(v) self.db.profile.BidStyle = v self:Update() end,
                        validate = {"text", "fade"}
					}
				}
			}
	end

	function mod:OnEnable()
		self:RegisterEvent("AH_LOADED")
	end

	function mod:OnDisable()
		if self:IsHooked("AuctionFrameBrowse_Update") then self:Unhook("AuctionFrameBrowse_Update") end
	end

	function mod:AH_LOADED()
		self:Hook("AuctionFrameBrowse_Update", true)
		self:UnregisterEvent("AH_LOADED")
	end
	
    function mod:Update()
        self.ShowPrice = self.db.profile.ShowPrice
        self.ShowBid = self.db.profile.ShowBid
        self.PriceStyle = self.db.profile.PriceStyle
        self.BidStyle = self.db.profile.BidStyle
    end

	function mod:AuctionFrameBrowse_Update()
        self.hooks["AuctionFrameBrowse_Update"]()

       	local numBatchAuctions, totalAuctions = GetNumAuctionItems("list")   
        if numBatchAuctions == 0 then return end
        
		local offset = FauxScrollFrame_GetOffset(BrowseScrollFrame)
		local index, button, itemName, moneyFrame
        local sM, spMoney, bidText, bT
        
		for i=1, NUM_BROWSE_TO_DISPLAY do
			index = offset + i + (NUM_AUCTION_ITEMS_PER_PAGE * AuctionFrameBrowse.page)
   			button = "BrowseButton"..i
            itemName = getglobal(button.."Name")		
            moneyFrame = getglobal(button.."MoneyFrame")
            moneyFrame:SetAlpha(1)

			local name, _, count, _, _, _, _, _, buyoutPrice, bidAmount, _, _ =  GetAuctionItemInfo("list", offset + i)

            if buyoutPrice > 0 and count > 1 and self.ShowPrice then
                local ep = floor(buyoutPrice/count)
                if self.PriceStyle == "short" then
                    spMoney = abc:FormatMoneyShort(ep, true)
                    sM = strlen(abc:FormatMoneyShort(ep)) + 4
                elseif self.PriceStyle == "full" then
                    spMoney = abc:FormatMoneyFull(ep, true)
                    sM = strlen(abc:FormatMoneyFull(ep)) + 4
                elseif self.PriceStyle == "condensed" then
                    spMoney = abc:FormatMoneyCondensed(ep, true)
                    sM = strlen(abc:FormatMoneyCondensed(ep)) + 4
                end
            end    

            if bidAmount > 0 and self.ShowBid then 
                if self.BidStyle == "text" then
                    bidText = " - |cffffff00" .. L["Bid"] .. "|r"
                    bT = strlen(L["Bid"]) + 3
                elseif self.BidStyle == "fade" then
                    moneyFrame:SetAlpha(.4)
                end
            end
            
           
            if not sM then sM = 0 end
            if not bT then bT = 0 end

            if spMoney then spMoney = " ("..spMoney..") " end
            if (sM + bT) > 0 then
                if (strlen(name)+(sM+bT)) > 40 then
                    name = strsub(name,0,(strlen(name) - (sM+bT))).."..." 
                end
                itemName:SetText(name..spMoney or ""..bidText or "") 
            end          
            bidText, spMoney, sM, bT = nil, nil, nil, nil
        end
    end
